API reference
=============

Core
----

.. currentmodule:: pyamica

.. autoclass:: AMICA
   :members:
   :special-members: __init__
   :undoc-members: False

.. minigallery:: pyamica.AMICA
   :add-heading:

MNE wrapper
-----------

.. autoclass:: AmicaICA
   :members:
   :special-members: __init__
   :undoc-members: False

.. minigallery:: pyamica.AmicaICA
   :add-heading:
